@@ -29,9 +29,9 @@ class ViewMode;
 class QMenu;
 
 template<class T>
-class QList;
+class QVector;
 
-typedef QList<Playlist *> PlaylistList;
+typedef QVector<Playlist *> PlaylistList;
 
 /**
  * This is the play list selection box that is by default on the left side of
@@ -67,7 +67,7 @@ public:
 
     Item *dropItem() const { return m_dropItem; }
 
-    void setupPlaylist(Playlist *playlist, const QString &iconName, Item *parentItem = 0);
+    void setupPlaylist(Playlist *playlist, const QString &iconName, Item *parentItem = nullptr);
 
 public slots:
     void paste();
@@ -84,6 +84,7 @@ protected:
 
 signals:
     void signalPlaylistDestroyed(Playlist *);
+    void signalMoveFocusAway(); // Handles keyboard scrolling up out of playlist
     void startupComplete(); ///< Emitted after playlists are loaded.
     void startFilePlayback(const FileHandle &file);
 
